package com.recordingblogs.orgenerator;

/**
This interface should be implemented by any generator to be used with the Orinj application
generator framework.  The framework allows Orinj to create wave files with specific
content (e.g., square waves, saw waves, sine sweeps).

You can redistribute this file, modify it, adapt it, translate it, and/or distribute 
the modified version, whether free of charge or not.  This file is distributed as is, without 
warranty of any kind.

@author      Anton Kamenov
@version     4.0
*/

public interface GeneratorInterface 
{
	/**
	 * Set the audio format of the wave to be created by this generator
	 * @param samplingRate  The new audio format sampling rate
	 * @param bitResolution The new audio format bit resolution
	 * @param channels 		The number of channels in the new audio format
	 */
	public abstract void setAudioFormat(float samplingRate, int bitResolution, int channels);
	
	/**
	 * Get the data to be contained in the generated wave.  This function
	 * should expect that successive calls to it will generate the whole wave,
	 * only one wave will be generated by the object that implements this interface,
	 * and that successive calls will result in successive byte buffers
	 * @param buf  The byte buffer in which the data should be placed.  The 
	 *             data will be written to the data file and should thus have
	 *             the appropriate format (e.g., bit resolution, sample rate,
	 *             endianism).
	 * @param gain Gain to be applied to the generated data
	 * @return The number of bytes generated.  This will typically be the length
	 *         of buf, but could be less (e.g., for the last buffer)
	 */
	public abstract int getData(byte [] buf, double gain);
	
    /** 
     * Set the language of the generator interface to be able to appropriate choose the strings
     * that should be shown for labels, tooltips, etc.  It is up to the author of the code
     * for the effect interfacer to decide how languages should be handled.  If not implementing
     * languages, leave this function empty.
     * @param languageCode Code for the language based on the three letter ISO 639-2
     */
    public abstract void setLanguage(String languageCode);
}
